Core developers
---------------

Core developers have commit privileges to the Lightkurve repository based on
their sustained contributions.  The core developers aim to govern the project
by consensus. If you believe you meet the criteria to be added as a core
developer, please open an issue!

- `Geert Barentsen <https://github.com/barentsen>`_ (lead maintainer)
- `Christina Hedges <https://github.com/christinahedges>`_
- `José Vinícius de Miranda Cardoso <https://github.com/mirca>`_
- `Thomas Barclay <https://github.com/mrtommyb>`_
- `Rebekah Hounsell <https://github.com/rebekah9969>`_
- `Jessie Dotson <https://github.com/jessie-dotson>`_
- `Nicholas Saunders <https://github.com/nksaunders>`_
- `Michael Gully-Santiago <https://github.com/gully>`_
- `Daniel Hey <https://github.com/danielhey>`_
- `Oliver Hall <https://github.com/ojhall94>`_



Contributors
------------
The following GitHub members directly contributed code and bugfixes:

- `Keaton Bell <https://github.com/keatonb>`_
- `Sheila Sagear <https://github.com/ssagear>`_
- `Ken Mighell <https://github.com/KenMighell>`_
- `Jose A. Lerma III <https://github.com/JoseALermaIII>`_
- `Emma Turtelboom <https://github.com/Emmavt>`_
- `Johnny Zhang <https://github.com/johnnyzhang295>`_
- `Ann Marie Cody <https://github.com/amcody>`_
- `Guy Davies <https://github.com/grd349>`_
- `Brennan Vincello <https://github.com/brennv>`_
- `Anand Sundaram <https://github.com/anand-sundaram-zocdoc>`_
- `Zachory K. Berta-Thompson <https://github.com/zkbt>`_
- `Peter Williams <https://github.com/pkgw>`_
- `Szabo Pal <https://github.com/zabop>`_
- `Jeff Smith <https://github.com/jcsmithhere>`_
- `Daniel Foreman-Mackey <https://github.com/dfm>`_
- `Michael Higgins <https://github.com/Higgins00>`_
- `Isabel Coleman <https://github.com/astrobel>`_
- `Colin J. Burke <https://github.com/burke86>`_
- `Andrew Vanderburg <https://github.com/avanderburg>`_
- `Sam Lee <https://github.com/orionlee>`_
- `Stephanie Douglas <https://github.com/stephtdouglas>`_
- `Kaiming Cui <https://github.com/ckm3>`_
- `Nuno Ramos Carvalho <https://github.com/nunorc>`_
- `Derek Homeier <https://github.com/dhomeier>`_
- `Scott Fleming <https://github.com/scfleming>`_
- `Susan Mullally <https://github.com/mustaric>`_
- `Jorge Martínez-Palomera <https://github.com/jorgemarpa>`_
- `Warrick Ball <https://github.com/warrickball>`_


Community
---------
We are grateful to the following community members for sharing corrections & suggestions which led to improvements to the package:

- `Clare Brasseur <https://github.com/ceb8>`_
- `Doug Caldwell <https://github.com/dacmess>`_
- TJ Jaffe
- `Elisa Quintana <https://github.com/elisaquintana>`_
- Jeff Van Cleve
- Ashley Villar
- `Benjamin Pope <https://github.com/benjaminpope>`_
- `J. K. Carlberg <https://github.com/jkcarlberg>`_
- `Brian Jackson <https://github.com/decaelus>`_
- `Rishi Paudel <https://github.com/rrpastro>`_
- `Marusa Zerjal <https://github.com/marusazerjal>`_
- `Michael Hippke <https://github.com/hippke>`_
- `Molnár László <https://github.com/lacalaca85>`_
- `Tom Wilson <https://github.com/Onoddil>`_
- `Tara Fetherolf <https://github.com/tfetherolf>`_
- `James Kuszlewicz <https://github.com/jsk389>`_
- `Timothy Bedding <https://github.com/timbedding>`_
- `Andy Tzanidakis <https://github.com/AndyTza>`_
- `Jeff Coughlin <https://github.com/JeffLCoughlin>`_
- `Dag Evensberget <https://github.com/svaberg>`_
- `Natalie Gosnell <https://github.com/nattieg>`_
- `Richard Elkins <https://github.com/texadactyl>`_
- `Saeed Hojjatpanah <https://github.com/saeedm31>`_
- `Simon J Murphy <https://github.com/SimonJMurphy>`_
- `Alex Lyttle <https://github.com/alexlyttle>`_
- `ansainbdg <https://github.com/ansainbdg>`_
- `newxr <https://github.com/newxr>`_
- `Tony (Yu-Ching) Chen <https://github.com/xyz3919>`_
- George Jacoby
- `Attila Bódi <https://github.com/astrobatty>`_
- Jennifer Burt
- Joshua Pepper
- `Joel Ong <https://github.com/darthoctopus>`_
- `Ben Rackham <https://github.com/brackham>`_
- `Andrea Guzman Mesa <https://github.com/aguzmanmesa>`_

This list is incomplete. Please open an issue if your name is missing!
